@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION);
-$VERSION = '0.03';
+$VERSION = '0.04';
 
 #----------------------------------------------------------------------------
 
@@ -35,7 +35,6 @@ sub get_info {
 
     for my $cmd (keys %commands) {
         $self->{cmds}{$cmd} = `$commands{$cmd} 2>/dev/null`;
-        $self->{info}{source} .= "$commands{$cmd}\n$self->{cmds}{$cmd}\n";
         $self->{cmds}{$cmd} =~ s/\s+$//s;
         $self->{info}{$cmd} = $self->{cmds}{$cmd}   if($cmd =~ /^[^_]/);
     }
@@ -48,6 +47,7 @@ sub get_info {
     $self->{info}{is32bit}  = $self->{info}{kname} !~ /64/ ? 1 : 0;
     $self->{info}{is64bit}  = $self->{info}{kname} =~ /64/ ? 1 : 0;
 
+    $self->{info}{source}{$commands{$_}} = $self->{cmds}{$_}    for(keys %commands);
     return $self->{info};
 }
 
